import { Context, Next } from 'koa';
import { middlewareLog } from '@utils/logger';

export default () => {
  const loggerMiddleware = middlewareLog();
  return async(ctx: Context, next: Next) => {
    // 静态文件不处理
    const isApi = /^\/api/.test(ctx.url);
    if (!isApi) {
      await next();
      return;
    };
    return loggerMiddleware(ctx, next)
      .catch(error => {
        const { body, status = 500, message } = error;
        const errorText = `res: ${JSON.stringify({ status, message, body })}`;
        ctx.$log.error(errorText);
        ctx.status = status
      });
  };
};
