import { Application, Context, DefaultContext } from 'koa';
import { IMiddleware } from 'koa-router';
import { RedisClient } from 'redis';
import response from '@utils/response';
import { InterfaceDB } from '../middlewares/localDb';

interface interfaceRedis {
  get: (key: string) => Promise<string>
  set: (key: string, value: string) => Promise<void>
  setex: (key: string, time: number, value: string) => Promise<void>
}
interface logFn {
  (message: any, ...args: any[]): void;
}
interface interfaceLog {
  trace: logFn
  debug: logFn
  info: logFn
  warn: logFn
  error: logFn
  fatal: logFn
  mark: logFn
}

declare module 'koa' {
  export interface Context extends DefaultContext {
    $redis: interfaceRedis
    $response: response
    $log: interfaceLog
    $db: InterfaceDB
  }
}
